@@ -93,7 +93,10 @@ def read_configobj(fpath, sheet_name=None, row_prefix="sniff"):
     config = ConfigObj(fpath, indent_type="    ", unrepr=True, write_empty_values=True)
     # transform sections to tabs and data to columns...
     if row_prefix == "sniff":
-        row_prefix = _sniff_row_prefix(config[config.sections[0]].sections[0])
+        try:
+            row_prefix = _sniff_row_prefix(config[config.sections[0]].sections[0])
+        except IndexError:
+            breakpoint()
     else:
         row_prefix = ROW_PREFIX
     for tabname, data in config.items():
