@@ -416,7 +416,13 @@ class DataFrameSchematizer:
         if self._is_units:
             # recover target units as specified in the validation schema
             _props = schema["properties"]
-            self._target_units = {k: v for k in _props if (v := _props[k].get("units"))}
+            # python >= 3.8 only
+            # self._target_units = {k: v for k in _props if (v := _props[k].get("units"))}
+            self._target_units = {}
+            for k in _props:
+                v = _props[k].get("units")
+                if v:
+                    self._target_units[k] = v
             # split dataframe in two parts: one that will be quantified, the other not
             # will be quantified the columns:
             #  * have a specified unit (source units)
